==> 1.1.7-dev.tar.gz: example/lib/ui/activity_data_insert.dart <==
import 'package:example/localization/labels.dart';
import 'package:example/ui/activity_data_delegate.dart';
import 'package:example/ui/activity_home.dart';
import 'package:example/ui/view/data_insert.dart';
import 'package:flutter/material.dart';
import 'package:flutterx_application/flutterx_application.dart';
import 'package:flutterx_utils/flutterx_utils.dart';

class DataInsertActivity extends StatefulWidget {
  static final ActivityRoute<String?> route = ActivityRoute(
      title: (_) => 'Insert Data',
      location: '/insert_activity',
      builder: (context, args) => DataInsertActivity._(initialValue: args['initialValue']));

  static Future<String?> open(BuildContext context, {String? initialValue}) =>
      route.open(context, args: {'initialValue': initialValue ?? ''});

  final String initialValue;

  const DataInsertActivity._({Key? key, required this.initialValue}) : super(key: key);

  @override
  State<DataInsertActivity> createState() => _DataInsertActivityState();
}

class _DataInsertActivityState extends State<DataInsertActivity> {
  final TextEditingController _controller = TextEditingController();

  @override
  void initState() {
    super.initState();
    _controller.text = widget.initialValue;
  }

  @override
  Widget build(BuildContext context) => Scaffold(
      appBar: AppBar(title: Text(labels.appName)),
      body: Center(
        child: Column(mainAxisAlignment: MainAxisAlignment.center, children: [
          DataInsertWidget(controller: _controller),
          divider,
          ..._navigationDemo(context),
        ]),
      ),
      floatingActionButton: FloatingActionButton(
          onPressed: () => Application.of(context).restart(),
          child: const Icon(Icons.check)));

  Iterable<Widget> _navigationDemo(BuildContext context) sync* {
    yield Text(labels.navigation);
    yield const SizedBox(height: 8);
    yield Padding(
        padding: const EdgeInsets.symmetric(horizontal: 16),
        child: Wrap(
            alignment: WrapAlignment.center,
            children: <Widget>[
              ElevatedButton(
                  onPressed: () => _controller.text.isEmpty
                      ? null
                      : DataDelegateActivity.openReplace(context,
                          message: 'Activity replaced\nResult has been returned', result: _controller.text),
                  child: Text(labels.openReplaceActivity)),
              ElevatedButton(
                  onPressed: () => DataDelegateActivity.openForward(context, message: 'This message will be returned'),
                  child: Text(labels.openForwardActivity)),
            ].interpolate(const SizedBox(width: 16)).toList(growable: false)));
  }
}

==> 1.1.11-dev.tar.gz: example/lib/ui/activity_data_insert.dart <==
import 'package:example/localization/labels.dart';
import 'package:example/ui/activity_data_delegate.dart';
import 'package:example/ui/activity_home.dart';
import 'package:example/ui/view/data_insert.dart';
import 'package:flutter/material.dart';
import 'package:flutterx_application/flutterx_application.dart';
import 'package:flutterx_utils/flutterx_utils.dart';

class DataInsertActivity extends StatefulWidget {
  static final ActivityRoute<String?> route = ActivityRoute(
      title: (_) => 'Insert Data',
      location: '/insert_activity',
      builder: (context, args) => DataInsertActivity._(initialValue: args['initialValue']));

  static Future<String?> open(BuildContext context, {String? initialValue}) =>
      route.open(context, args: {'initialValue': initialValue ?? ''});

  final String initialValue;

  const DataInsertActivity._({Key? key, required this.initialValue}) : super(key: key);

  @override
  State<DataInsertActivity> createState() => _DataInsertActivityState();
}

class _DataInsertActivityState extends State<DataInsertActivity> {
  final TextEditingController _controller = TextEditingController();

  @override
  void initState() {
    super.initState();
    _controller.text = widget.initialValue;
  }

  @override
  Widget build(BuildContext context) => WillPopScope(
      child: Scaffold(
          appBar: AppBar(title: Text(labels.appName)),
          body: Center(
            child: Column(mainAxisAlignment: MainAxisAlignment.center, children: [
              DataInsertWidget(controller: _controller),
              divider,
              ..._navigationDemo(context),
            ]),
          ),
          floatingActionButton:
              FloatingActionButton(onPressed: () => Application.of(context).restart(), child: const Icon(Icons.check))),
      onWillPop: () => Future.delayed(const Duration(milliseconds: 800), () => true));

  Iterable<Widget> _navigationDemo(BuildContext context) sync* {
    yield Text(labels.navigation);
    yield const SizedBox(height: 8);
    yield Padding(
        padding: const EdgeInsets.symmetric(horizontal: 16),
        child: Wrap(
            alignment: WrapAlignment.center,
            children: <Widget>[
              ElevatedButton(
                  onPressed: () => _controller.text.isEmpty
                      ? null
                      : DataDelegateActivity.openReplace(context,
                          message: 'Activity replaced\nResult has been returned', result: _controller.text),
                  child: Text(labels.openReplaceActivity)),
              ElevatedButton(
                  onPressed: () => DataDelegateActivity.openForward(context, message: 'This message will be returned'),
                  child: Text(labels.openForwardActivity)),
            ].interpolate(const SizedBox(width: 16)).toList(growable: false)));
  }
}
